@@ -1,4 +1,5 @@
 import logging
+from .version import __version__
 from functools import lru_cache
 from glob import glob
 from os import environ, path
@@ -59,7 +60,7 @@ API_RESPONSE_MODELS = [
 ]
 
 CLIENT_NAME = "Curvenote Python Client"
-CLIENT_VERSION = "0.0.1"
+CLIENT_VERSION = __version__
 if environ.get("CURVENOTE_ENV") == "development":
     print(
         r"""
@@ -70,7 +71,8 @@ if environ.get("CURVENOTE_ENV") == "development":
 
     """
     )
-    API_URL = "http://localhost:8083"
+    API_URL = environ.get("CURVENOTE_API", "http://localhost:8083")
+    print(f"Accessing API at: {API_URL}")
     SITE_URL = "https://localhost:3000"
 else:
     API_URL = "https://api.curvenote.com"
@@ -110,14 +112,13 @@ class Session:
     def _get_models(
         self, url: str, model: Type[BaseModel], limit: int = 200
     ) -> Iterator[BaseModel]:
-        next_url = f"{url}?limit={limit}"
+        next_url = update_query(url, {"limit": limit})
         while next_url:
             resp = self._get(next_url)
             obj_list = model(**resp.json())
             for obj in obj_list.items:
                 yield obj
-            next_url = None
-            # next_url = obj_list.links.next
+            next_url = getattr(obj_list.links, "next", None)
 
     def _post(self, url: str, json_dict: dict) -> requests.Response:
         resp = self._session.post(url, json=json_dict)
@@ -207,10 +208,12 @@ class Session:
         )
         possible_blocks = []
         blocks_url = project_obj.links.blocks
+        logging.debug(blocks_url)
         if kind:
             blocks_url = update_query(blocks_url, {"kind": kind})
         for block_obj in self._get_models(blocks_url, BlockList):
             if block_obj.id.block == block:
+                logging.debug(f"found block by id {block}")
                 return block_obj
             if block in (block_obj.name, block_obj.title):
                 possible_blocks.append(block_obj)
